--[[
	Copyright (C) Udorn (Blackhand)
--]]

local viewType = "QuestSelectorEntry"
local version = 1
local YakaGui = LibStub("YakaGui", true)
local info = YakaGui:GetViewInfo(viewType) 
if (info and info.version >= version) then 
	return 
end

qmstr = qmstr or {}
qmstr.QuestSelectorEntry = {}
qmstr.QuestSelectorEntry.prototype = {}
qmstr.QuestSelectorEntry.metatable = {__index = qmstr.QuestSelectorEntry.prototype}
setmetatable(qmstr.QuestSelectorEntry.prototype, {__index = yaka.Container.prototype})

qmstr.QuestSelectorEntry.info = {viewType = viewType, version = version}
qmstr.QuestSelectorEntry.GetViewInfo = function()
	return qmstr.QuestSelectorEntry.info
end

qmstr.QuestSelectorEntry.childViews = {}

local log = vendor.Debug:new("QuestSelectorEntry")

local function _OnCheck(info)
	local self = info.arg
	if (info.value) then
		ExpandQuestHeader(self.cfg.questIndex)
	else
		CollapseQuestHeader(self.cfg.questIndex)
	end
end

--[[ 
	Creates a new instance.
--]]
function qmstr.QuestSelectorEntry:new(cfgIn, parent)
	local instance = setmetatable({}, self.metatable)
	instance:InitCfg(cfgIn)
	instance:InitFrame(parent)
	return instance
end

function qmstr.QuestSelectorEntry.prototype:InitCfg(cfgIn)
	yaka.Container.prototype.InitCfg(self, cfgIn)
	
	local cfg = self.cfg
	cfg.questIndex = cfgIn.questIndex 
	cfg.layout = {
		layoutType = "LinearLayout",
		vertical = false
	}
end

function qmstr.QuestSelectorEntry.prototype:InitFrame(parent)
	yaka.Container.prototype.InitFrame(self, parent)
	self.checkbox = YakaGui:CreateView({
			viewType = "Checkbox",
			order = 1,
			width = 16,
			height = 16,
			setValue = _OnCheck,
    		arg = self
	})
	self:AddChildView(self.checkbox)
	self.text = YakaGui:CreateView({
			viewType = "Text",
			order = 2,
			width = "fill",
			height = 16,
    		arg = self
	})
	self:AddChildView(self.text)
	
	self:SetQuestIndex(self.cfg.questIndex)
end

function qmstr.QuestSelectorEntry.prototype:SetQuestIndex(questIndex)
	self.cfg.questIndex = questIndex
	local questTitle, level, questTag, suggestedGroup, isHeader, isCollapsed, isComplete, isDaily, questID = GetQuestLogTitle(self.cfg.questIndex)
	self.text:SetText(questTitle)
	log:Debug("questIndex [%s] text [%s]", questIndex, questTitle)
	self.checkbox:SetChecked(not isCollapsed)
end

-- register view

YakaGui:RegisterViewType(qmstr.QuestSelectorEntry)